"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_table_plain_1 = require("@dccs/react-table-plain");
var DataGridStateContext_1 = require("./DataGridStateContext");
function DataGridPlain(props) {
    // Do we have a custom context,...
    var stateContext = React.useContext(DataGridStateContext_1.DataGridState);
    var privateReducer = React.useReducer(DataGridStateContext_1.reducer, createDefaultState()); // ...if not, we need to create the state.
    if (stateContext === undefined) {
        stateContext = { state: privateReducer[0], dispatch: privateReducer[1] };
    }
    var _a = stateContext, state = _a.state, dispatch = _a.dispatch;
    var _b = React.useState([]), data = _b[0], setData = _b[1];
    var _c = React.useState(false), loading = _c[0], setLoading = _c[1];
    var _d = React.useState(false), error = _d[0], setError = _d[1];
    React.useEffect(function () {
        setLoading(true);
        setError(false);
        props
            .onLoadData(state.page + 1, state.rowsPerPage, state.orderBy ? state.orderBy.prop : "", state.desc, state.filter)
            .then(function (_a) {
            var d = _a.data, total = _a.total;
            dispatch({ type: "set-total", payload: total });
            setData(d);
            setLoading(false);
        })
            .catch(function () {
            setLoading(false);
            setError(true);
        });
    }, [
        state.rowsPerPage,
        state.page,
        state.orderBy,
        state.desc,
        state.filter,
        state.reloadDummy,
        props,
        dispatch
    ]);
    function load() {
        setLoading(true);
        setError(false);
        props
            .onLoadData(state.page + 1, state.rowsPerPage, state.orderBy ? state.orderBy.prop : "", state.desc, state.filter)
            .then(function (_a) {
            var d = _a.data, total = _a.total;
            dispatch({ type: "set-total", payload: total });
            setData(d);
            setLoading(false);
        })
            .catch(function () {
            setLoading(false);
            setError(true);
        });
    }
    function handleChangePage(page) {
        dispatch({ type: "set-page", payload: page });
    }
    function handleChangeRowsPerPage(rows) {
        dispatch({ type: "set-rowsperpage", payload: rows });
    }
    function handleChangeOrderBy(colDef) {
        var desc = false;
        if (state.orderBy && state.orderBy.prop === colDef.prop) {
            desc = !state.desc;
        }
        dispatch({ type: "set-orderBy", payload: { orderBy: colDef, desc: desc } });
    }
    function handleChangeFilter(colDef, value) {
        var _a;
        dispatch({ type: "set-filter", payload: (_a = {}, _a[colDef.prop] = value, _a) });
    }
    function renderTable() {
        var ps = {
            data: data,
            colDef: props.colDef,
            orderedBy: state.orderBy,
            desc: state.desc,
            onChangeOrderBy: handleChangeOrderBy,
            onChangeFilter: handleChangeFilter,
            onRowClick: props.onRowClick,
            subComponent: props.subComponent
        };
        if (props.renderTable != null) {
            return props.renderTable(ps);
        }
        return React.createElement(react_table_plain_1.TablePlain, __assign({}, ps));
    }
    function renderLoading() {
        if (props.renderLoading != null) {
            return props.renderLoading();
        }
        return React.createElement("h5", null, "Loading...");
    }
    function renderError() {
        if (props.renderError != null) {
            return props.renderError(load);
        }
        return (React.createElement("p", { style: { width: "100%", background: "red", padding: 16 } },
            React.createElement("p", null, "Die Daten konnten nicht geladen werden."),
            React.createElement("p", null,
                React.createElement("button", { onClick: function () { return load(); } }, "Neu laden"))));
    }
    function renderPaging() {
        if (props.renderPaging != null) {
            return props.renderPaging(__assign({}, state, { handleChangePage: handleChangePage,
                handleChangeRowsPerPage: handleChangeRowsPerPage }));
        }
        return React.createElement("strong", null, "No paging available right now. Check back later...");
    }
    if (error) {
        return renderError();
    }
    return (React.createElement("div", { style: { position: "relative", overflowX: "auto", width: "100%" } },
        loading && renderLoading(),
        renderTable(),
        props.disablePaging !== true && renderPaging()));
}
exports.DataGridPlain = DataGridPlain;
function createDefaultState() {
    return {
        rowsPerPage: 10,
        page: 0,
        total: 0,
        orderBy: undefined,
        desc: false,
        filter: {},
        reloadDummy: false
    };
}
